Linux MM tree latest commits
 help / color / mirror / Atom feed
* + reiser4-remove-inode_setattr.patch added to -mm tree
@ 2010-07-08 22:11 akpm
  0 siblings, 0 replies; only message in thread
From: akpm @ 2010-07-08 22:11 UTC (permalink / raw)
  To: mm-commits; +Cc: edward.shishkin


The patch titled
     reiser4: remove inode_setattr
has been added to the -mm tree.  Its filename is
     reiser4-remove-inode_setattr.patch

Before you just go and hit "reply", please:
   a) Consider who else should be cc'ed
   b) Prefer to cc a suitable mailing list as well
   c) Ideally: find the original patch on the mailing list and do a
      reply-to-all to that, adding suitable additional cc's

*** Remember to use Documentation/SubmitChecklist when testing your code ***

See http://userweb.kernel.org/~akpm/stuff/added-to-mm.txt to find
out what to do about this

The current -mm tree may be found at http://userweb.kernel.org/~akpm/mmotm/

------------------------------------------------------
Subject: reiser4: remove inode_setattr
From: Edward Shishkin <edward.shishkin@gmail.com>

Adjust reiser4 to vfs changes:
inode_setattr() has been removed.

Signed-off-by: Edward Shishkin <edward.shishkin@gmail.com>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
---

 fs/reiser4/plugin/inode_ops.c |   10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)

diff -puN fs/reiser4/plugin/inode_ops.c~reiser4-remove-inode_setattr fs/reiser4/plugin/inode_ops.c
--- a/fs/reiser4/plugin/inode_ops.c~reiser4-remove-inode_setattr
+++ a/fs/reiser4/plugin/inode_ops.c
@@ -446,7 +446,9 @@ int reiser4_setattr_common(struct dentry
 	assert("nikita-3119", !(attr->ia_valid & ATTR_SIZE));
 
 	/*
 	 * grab disk space and call standard inode_setattr().
 	 */
 	result = setattr_reserve(reiser4_tree_by_inode(inode));
 	if (!result) {
@@ -460,9 +462,9 @@ int reiser4_setattr_common(struct dentry
 				return result;
 			}
 		}
-		result = inode_setattr(inode, attr);
-		if (!result)
-			reiser4_update_sd(inode);
+		setattr_copy(inode, attr);
+		mark_inode_dirty(inode);
+		result = reiser4_update_sd(inode);
 	}
 
 	context_set_commit_async(ctx);
_

Patches currently in -mm which might be from edward.shishkin@gmail.com are

vfs-add-super-operation-writeback_inodes.patch
vfs-add-super-operation-writeback_inodes-fix.patch
vfs-take-2add-set_page_dirty_notag.patch
vfs-change-writeback_inodes-signature.patch
reiser4.patch
reiser4-rename-quota-methods.patch
reiser4-remove-inode_setattr.patch
reiser4-writeback_inodes-implementation.patch
reiser4-writeback_inodes-implementation-fix.patch
reiser4-writeback_inodes-implementation-adjust-to-writeback-changes.patch
reiser4-fixup-checkin-checkout-jnodes-for-entd.patch
reiser4-fixups.patch
reiser4-broke.patch
reiser4-change-fsync-signature.patch
reiser4-enable.patch


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2010-07-08 22:12 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -446,7 +446,9 @@ int reiser4_setattr_common(struct dentry
 
 	/*
-	 * grab disk space and call standard inode_setattr().
+	 * grab disk space and call standard
+	 * setattr_copy();
+	 * mark_inode_dirty().
 	 */
 	result = setattr_reserve(reiser4_tree_by_inode(inode));
2010-07-08 22:11 + reiser4-remove-inode_setattr.patch added to -mm tree akpm

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox